@@ -6,12 +6,11 @@ use strict;
 use File::Basename;
 use File::Spec::Functions;
 use File::Compare ();
-use File::Glob qw(bsd_glob);
 use Carp;
 
 use vars qw($VERSION);
 
-$VERSION = '0.5.1';
+$VERSION = '0.01';
 
 # ----------------------------------------------------------------------------
 # Private methods
@@ -23,10 +22,10 @@ sub _dir_compare
 
   # Glob $dir1 and $dir2
   my (%d1, %d2);
-  $d1{basename $_} = 1 foreach bsd_glob(catfile($dir1, ".*"));
-  $d1{basename $_} = 1 foreach bsd_glob(catfile($dir1, "*"));
-  $d2{basename $_} = 1 foreach bsd_glob(catfile($dir2, ".*"));
-  $d2{basename $_} = 1 foreach bsd_glob(catfile($dir2, "*"));
+  $d1{basename $_} = 1 foreach glob(catfile($dir1, ".*"));
+  $d1{basename $_} = 1 foreach glob(catfile($dir1, "*"));
+  $d2{basename $_} = 1 foreach glob(catfile($dir2, ".*"));
+  $d2{basename $_} = 1 foreach glob(catfile($dir2, "*"));
 
   # Prune dot dirs
   delete $d1{curdir()} if $d1{curdir()};
@@ -49,21 +48,11 @@ sub _dir_compare
     }
     # In both
     else {
-      # Both symlinks
-      if (-l $f1 && -l $f2) {
-        my $t1 = readlink $f1 or croak "Cannot read symlink $f1: $!";
-        my $t2 = readlink $f2 or croak "Cannot read symlink $f2: $!";
-        $sub->($f1, $f2) if $t1 ne $t2;
-      }
-      # One symlink (i.e. different)
-      elsif (-l $f1 || -l $f2) {
-        $sub->($f1, $f2);
-      }
       # Both directories
-      elsif (-d $f1 && -d $f2) {
+      if (-d $f1 && -d $f2) {
         $self->_dir_compare($f1, $f2, $sub, $opts);
       }
-      # One directory (i.e. different)
+      # One directory
       elsif (-d $f1 || -d $f2) {
         $sub->($f1, $f2);
       }
@@ -128,9 +117,9 @@ callbacks.
   File::DirCompare->compare($dir1, $dir2, sub {
     my ($a, $b) = @_;
     if (! $b) {
-      printf "Only in %s: %s\n", dirname($a), basename($a);
+      printf "Only in $dir1: %s\n", basename($a);
     } elsif (! $a) {
-      printf "Only in %s: %s\n", dirname($b), basename($b);
+      printf "Only in $dir2: %s\n", basename($b);
     } else {
       print "Files $a and $b differ\n";
     }
@@ -138,7 +127,7 @@ callbacks.
 
   # Version-control like Deleted/Added/Modified listing
   my (@listing, @modified);     # use closure to collect results
-  File::DirCompare->compare('old_tree', 'new_tree', sub {
+  File::DirCompare->compare('old_tree', 'new_tree'), sub {
     my ($a, $b) = @_;
     if (! $b) {
       push @listing, "D   $a";
@@ -243,16 +232,13 @@ directory walking code I've adapted for this module), but a simpler
 reporting-only interface, something like the first example in the 
 SYNOPSIS above.
 
-=head1 AUTHOR AND CREDITS
+=head1 AUTHOR
 
 Gavin Carr <gavin@openfusion.com.au>
 
-Thanks to Robin Barker for a bug report and fix for glob problems
-with whitespace.
-
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2007 by Gavin Carr.
+Copyright 2006 by Gavin Carr.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
